==> Microsoft-AdCenter-8.00_01.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V6/ReportingService/TacticChannelReportColumn.pm <==
package Microsoft::AdCenter::V6::ReportingService::TacticChannelReportColumn;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

sub AccountId {
    return 'AccountId';
}

sub AccountName {
    return 'AccountName';
}

sub AccountNumber {
    return 'AccountNumber';
}

sub AdGroupId {
    return 'AdGroupId';
}

sub AdGroupName {
    return 'AdGroupName';
}

sub Assists {
    return 'Assists';
}

sub CampaignId {
    return 'CampaignId';
}

sub CampaignName {
    return 'CampaignName';
}

sub Channel {
    return 'Channel';
}

sub Conversions {
    return 'Conversions';
}

sub FunnelConversionRate {
    return 'FunnelConversionRate';
}

sub Goal {
    return 'Goal';
}

sub Keyword {
    return 'Keyword';
}

sub KeywordId {
    return 'KeywordId';
}

sub ReturnOnAdSpend {
    return 'ReturnOnAdSpend';
}

sub Revenue {
    return 'Revenue';
}

sub Spend {
    return 'Spend';
}

sub Step1Count {
    return 'Step1Count';
}

sub Step2Count {
    return 'Step2Count';
}

sub Step3Count {
    return 'Step3Count';
}

sub Step4Count {
    return 'Step4Count';
}

sub Step5Count {
    return 'Step5Count';
}

sub Tactic {
    return 'Tactic';
}

sub ThirdPartyAdGroup {
    return 'ThirdPartyAdGroup';
}

sub ThirdPartyCampaign {
    return 'ThirdPartyCampaign';
}

sub ThirdPartyTerm {
    return 'ThirdPartyTerm';
}

sub TimePeriod {
    return 'TimePeriod';
}

1;

==> Microsoft-AdCenter-8.00_02.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V6/ReportingService/TacticChannelReportColumn.pm <==
package Microsoft::AdCenter::V6::ReportingService::TacticChannelReportColumn;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V6::ReportingService::TacticChannelReportColumn - Represents "TacticChannelReportColumn" in Microsoft AdCenter Reporting Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

AccountId
AccountName
AccountNumber
AdGroupId
AdGroupName
Assists
CampaignId
CampaignName
Channel
Conversions
FunnelConversionRate
Goal
Keyword
KeywordId
ReturnOnAdSpend
Revenue
Spend
Step1Count
Step2Count
Step3Count
Step4Count
Step5Count
Tactic
ThirdPartyAdGroup
ThirdPartyCampaign
ThirdPartyTerm
TimePeriod

=cut

sub AccountId {
    return 'AccountId';
}

sub AccountName {
    return 'AccountName';
}

sub AccountNumber {
    return 'AccountNumber';
}

sub AdGroupId {
    return 'AdGroupId';
}

sub AdGroupName {
    return 'AdGroupName';
}

sub Assists {
    return 'Assists';
}

sub CampaignId {
    return 'CampaignId';
}

sub CampaignName {
    return 'CampaignName';
}

sub Channel {
    return 'Channel';
}

sub Conversions {
    return 'Conversions';
}

sub FunnelConversionRate {
    return 'FunnelConversionRate';
}

sub Goal {
    return 'Goal';
}

sub Keyword {
    return 'Keyword';
}

sub KeywordId {
    return 'KeywordId';
}

sub ReturnOnAdSpend {
    return 'ReturnOnAdSpend';
}

sub Revenue {
    return 'Revenue';
}

sub Spend {
    return 'Spend';
}

sub Step1Count {
    return 'Step1Count';
}

sub Step2Count {
    return 'Step2Count';
}

sub Step3Count {
    return 'Step3Count';
}

sub Step4Count {
    return 'Step4Count';
}

sub Step5Count {
    return 'Step5Count';
}

sub Tactic {
    return 'Tactic';
}

sub ThirdPartyAdGroup {
    return 'ThirdPartyAdGroup';
}

sub ThirdPartyCampaign {
    return 'ThirdPartyCampaign';
}

sub ThirdPartyTerm {
    return 'ThirdPartyTerm';
}

sub TimePeriod {
    return 'TimePeriod';
}

1;
